@@ -246,6 +246,11 @@ class StateGlobal(StateGlobalExternal):
         info = self.key_info(key)
         return tl.App.globalPut(tl.Bytes(info.key), value)
 
+    def drop(self, key: Key) -> tl.Expr:
+        """Build the expression to drop the state `key`"""
+        info = self.key_info(key)
+        return tl.App.globalDel(tl.Bytes(info.key))
+
     def constructor(self) -> tl.Expr:
         """
         Build the expression to set the initial state values for those keys
@@ -308,13 +313,21 @@ class StateLocal(StateLocalExternal):
     def __init__(
         self,
         keys: List[State.KeyInfo],
+        account: tl.Expr = None,
     ):
         """
-        See `StateLocalExternal.__init__` but for only the current app and the
-        transaction sender.
+        See `StateLocalExternal.__init__` but for only the current app.
+
+        The account whose local state is accessed can be specified with
+        `account`, and defaults to the transaction sender.
         """
-        # only state of the current application for the sender can be written
-        super().__init__(keys, tl.Global.current_application_id(), tl.Txn.sender())
+        # only state of the current application can be written, but any
+        # account which has opted-in can be modified
+        super().__init__(
+            keys,
+            tl.Global.current_application_id(),
+            account if account is not None else tl.Txn.sender(),
+        )
 
     def get(self, key: Key) -> tl.Expr:
         """See `StateGlobal.get`."""
@@ -326,6 +339,11 @@ class StateLocal(StateLocalExternal):
         info = self.key_info(key)
         return tl.App.localPut(self.account, tl.Bytes(info.key), value)
 
+    def drop(self, key: Key) -> tl.Expr:
+        """See `StateGlobal.drop`."""
+        info = self.key_info(key)
+        return tl.App.localDel(self.account, tl.Bytes(info.key))
+
     def constructor(self) -> tl.Expr:
         """See `StateGlobal.constructor`."""
         return tl.Seq(
